[FIX] stock: replenish avoid to compute everything

Some people create a lot of references but don't use them in their
stock. To avoid a big computation time to know the quantities for
each product in each location, we only compute it for product having
`stock.move`

For a database with 60 000 `product.product` and 6 replenish locations
but with 100 `stock.move` it goes from 50s to 0.5s

opw-3144094

closes odoo/odoo#111628

X-original-commit: 95ddf47a1ca105d9de8fec01c69fbe53b720bfe2
Signed-off-by: William Henrotin (whe) <whe@odoo.com>
Signed-off-by: Arnold Moyaux (arm) <arm@odoo.com>
This commit is contained in:
Arnold Moyaux
2023-02-01 22:30:59 +01:00
parent 52df6a3a6b
commit 2ea54a3949
+1 -1
View File
@@ -571,4 +571,4 @@ class StockWarehouseOrderpoint(models.Model):
return datetime.combine(self.lead_days_date, time.min)
def _get_orderpoint_products(self):
return self.env['product.product'].search([('type', '=', 'product')])
return self.env['product.product'].search([('type', '=', 'product'), ('stock_move_ids', '!=', False)])